@@ -5,35 +5,25 @@ import requests
 
 
 class ArticlesInfo(object):
-    """
-    登录WeChat，获取更加详细的推文信息。如点赞数、阅读数、评论等
-    """
-    def __init__(self,
-                 appmsg_token,
-                 cookie,
-                 proxies={
-                     'http': None,
-                     'https': None
-                 }):
+    """登录WeChat，获取更加详细的推文信息。如点赞数、阅读数、评论等"""
+
+    def __init__(self, appmsg_token, cookie, proxies={"http": None, "https": None}):
         """
         初始化参数
+
         Parameters
         ----------
         cookie: str
             点开微信公众号文章抓包工具获取的cookie
         appmsg_token: str
             点开微信公众号文章抓包工具获取的appmsg_token
-
-        Returns
-        -------
-        None
         """
         self.s = requests.session()
+        self.s.trust_env = False
         self.appmsg_token = appmsg_token
         self.headers = {
-            "User-Agent":
-            "Mozilla/5.0 AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0Chrome/57.0.2987.132 MQQBrowser/6.2 Mobile",
-            "Cookie": cookie
+            "User-Agent": "Mozilla/5.0 AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0Chrome/57.0.2987.132 MQQBrowser/6.2 Mobile",
+            "Cookie": cookie,
         }
         self.data = {
             "is_only_read": "1",
@@ -45,24 +35,21 @@ class ArticlesInfo(object):
     def __verify_url(self, article_url):
         """
         简单验证文章url是否符合要求
+
         Parameters
         ----------
         article_url: str
             文章链接
-
-        Returns
-        -------
-        None
         """
         verify_lst = ["mp.weixin.qq.com", "__biz", "mid", "sn", "idx"]
         for string in verify_lst:
             if string not in article_url:
-                raise Exception(
-                    "params is error, please check your article_url")
+                raise Exception("params is error, please check your article_url")
 
     def read_like_nums(self, article_url):
         """
         获取阅读数和点赞数
+
         Parameters
         ----------
         article_url: str
@@ -75,14 +62,18 @@ class ArticlesInfo(object):
         """
         try:
             appmsgstat = self.__get_appmsgext(article_url)["appmsgstat"]
-            return appmsgstat["read_num"], appmsgstat["like_num"], appmsgstat[
-                "old_like_num"]
+            return (
+                appmsgstat["read_num"],
+                appmsgstat["like_num"],
+                appmsgstat["old_like_num"],
+            )
         except Exception:
             raise Exception("params is error, please check your article_url")
 
     def comments(self, article_url):
         """
         获取文章评论
+
         Parameters
         ----------
         article_url: str
@@ -90,7 +81,8 @@ class ArticlesInfo(object):
 
         Returns
         -------
-        json:
+        json::
+
             {
                 "base_resp": {
                     "errmsg": "ok",
@@ -129,11 +121,10 @@ class ArticlesInfo(object):
         __biz, _, idx, _ = self.__get_params(article_url)
         getcomment_url = "https://mp.weixin.qq.com/mp/appmsg_comment?action=getcomment&__biz={}&idx={}&comment_id={}&limit=100"
         try:
-            url = getcomment_url.format(__biz, idx,
-                                        self.__get_comment_id(article_url))
-            comment_json = self.s.get(url,
-                                      headers=self.headers,
-                                      proxies=self.proxies).json()
+            url = getcomment_url.format(__biz, idx, self.__get_comment_id(article_url))
+            comment_json = self.s.get(
+                url, headers=self.headers, proxies=self.proxies
+            ).json()
         except Exception as e:
             print(e)
             comment_json = {}
@@ -142,6 +133,7 @@ class ArticlesInfo(object):
     def __get_comment_id(self, article_url):
         """
         获取comment_id
+
         Parameters
         ----------
         article_url: str
@@ -154,13 +146,13 @@ class ArticlesInfo(object):
         """
         res = self.s.get(article_url, data=self.data, proxies=self.proxies)
         # 使用正则提取comment_id
-        comment_id = re.findall(r'comment_id = "\d+"',
-                                res.text)[0].split(" ")[-1][1:-1]
+        comment_id = re.findall(r'comment_id = "\d+"', res.text)[0].split(" ")[-1][1:-1]
         return comment_id
 
     def __get_params(self, article_url):
         """
         解析文章url, 获取必要的请求参数
+
         Parameters
         ----------
         article_url: str
@@ -176,7 +168,7 @@ class ArticlesInfo(object):
 
         # 切分url, 提取相应的参数
         string_lst = article_url.split("?")[1].split("&")
-        dict_value = [string[string.index("=") + 1:] for string in string_lst]
+        dict_value = [string[string.index("=") + 1 :] for string in string_lst]
         __biz, mid, idx, sn, *_ = dict_value
         sn = sn[:-3] if sn[-3] == "#" else sn
 
@@ -185,6 +177,7 @@ class ArticlesInfo(object):
     def __get_appmsgext(self, article_url):
         """
         获取每篇文章具体信息
+
         Parameters
         ----------
         article_url: str
@@ -193,27 +186,27 @@ class ArticlesInfo(object):
         Returns
         -------
         json:
-            文章具体信息的json
-            {
-                'advertisement_info': [],
-                'advertisement_num': 0,
-                'appmsgstat': {'is_login': True,
-                'like_num': 12,
-                'liked': False,
-                'read_num': 288,
-                'real_read_num': 0,
-                'ret': 0,
-                'show': True},
-                'base_resp': {'wxtoken': 2045685972},
-                'reward_head_imgs': []
-            }
+            文章具体信息的json::
+
+                {
+                    'advertisement_info': [],
+                    'advertisement_num': 0,
+                    'appmsgstat': {'is_login': True,
+                    'like_num': 12,
+                    'liked': False,
+                    'read_num': 288,
+                    'real_read_num': 0,
+                    'ret': 0,
+                    'show': True},
+                    'base_resp': {'wxtoken': 2045685972},
+                    'reward_head_imgs': []
+                }
         """
         __biz, mid, idx, sn = self.__get_params(article_url)
 
         # 将params参数换到data中请求。这一步貌似不换也行
         origin_url = "https://mp.weixin.qq.com/mp/getappmsgext?"
-        appmsgext_url = origin_url + "appmsg_token={}&x5=0".format(
-            self.appmsg_token)
+        appmsgext_url = origin_url + "appmsg_token={}&x5=0".format(self.appmsg_token)
         self.data["__biz"] = __biz
         self.data["mid"] = mid
         self.data["sn"] = sn
@@ -221,12 +214,10 @@ class ArticlesInfo(object):
 
         # appmsgext_url = origin_url + "__biz={}&mid={}&sn={}&idx={}&appmsg_token={}&x5=1".format(
         #     __biz, mid, sn, idx, self.appmsg_token)
-        appmsgext_json = requests.post(appmsgext_url,
-                                       headers=self.headers,
-                                       data=self.data,
-                                       proxies=self.proxies).json()
+        appmsgext_json = requests.post(
+            appmsgext_url, headers=self.headers, data=self.data, proxies=self.proxies
+        ).json()
 
         if "appmsgstat" not in appmsgext_json.keys():
-            raise Exception(
-                "get info error, please check your cookie and appmsg_token")
+            raise Exception("get info error, please check your cookie and appmsg_token")
         return appmsgext_json
